#!/usr/bin/python3
"""
Allow buildbot to run jobs dynamically defined a a project repo
Requires docker
"""

# TODO: change "ghcontext" in master.cfg to interpolate the job name
# TODO: write upload script
# TODO: write hook (perhaps the default hook is ok), authentication for hook
# TODO: write hook job, maybe also a dockerfile?
# TODO: what to do about non-docker jobs

from os import walk
from os.path import exists, isfile, join, listdir
import requests

request_url = "https://buildbot.sysdeploy.org/change_hook/base"
request_headers = {
    'Content-Type': 'application/x-www-form-urlencoded',
    'Accept': 'text/plain'
}
request_data = {
    'repository': 'git@git.bitmessage.org:Sysdeploy/buildbot-scripts.git',
    'project': 'testproject',
    'author': 'cloud-init',
    'comments': 'testcomment',
}

ty = 'child_hook'
hn = 'buildbot.sysdeploy.org' #hostname here(required?)
addn = ',"build_script_available":"{build_script_available}","test_script_available":"{test_script_available}"'


def list_jobs(directory=".buildbot"):
    """
    list jobs found in a directory
    """
    results = []
    for _ in next(walk(directory))[1]:
        if exists(join(directory, _, "Dockerfile")) \
            and (exists(join(directory, _, "build.sh"))
                 or exists(join(directory, _, "test.sh"))
                 ):
            results.append(_)

    return results


def find_artifacts(directory="out"):
    """
    find artifacts (any file) in a directory
    """
    for _ in listdir(directory):
        if not isfile(join(directory, _)):
            continue
        return join(directory, _)

def trigger_child_hooks(directory=".buildbot"):
    
    # List all jobs in the directory
    jobs = list_jobs(directory)

    # Check if build.sh or test.sh exists in each of the jobs
    for job in jobs:
        build_script_exists = False
        test_script_exists = False
        if exists(join(directory, job, "build.sh")):
            build_script_exists = True
        if exists(join(directory, job, "test.sh")):
            test_script_exists = True
        
        addn = addn.format(build_script_available=build_script_exists, test_script_available=test_script_exists)
        
        # make a post request
        request_data['properties'] = '{"node":{hn},"type":{ty}{addn}"}'.format(hn=hn, ty=ty, addn=addn)
        requests.post(request_url, headers=request_headers, data=request_data)

if __name__ == "__main__":
    trigger_child_hooks()